@@ -2,7 +2,6 @@
 
 import asyncio
 import datetime
-import json
 import logging
 
 import aiohttp  # type: ignore
@@ -39,7 +38,7 @@ class OpenEVSEWebsocket:
         self._user = user
         self._password = password
         self.callback = callback
-        self._state = None
+        self._state = STATE_DISCONNECTED
         self.failed_attempts = 0
         self._error_reason = None
         self._client = None
@@ -148,20 +147,28 @@ class OpenEVSEWebsocket:
         """Send ping requests to websocket."""
         if self._ping and self._pong:
             time_delta = self._pong - self._ping
-            if time_delta < 0:
+            if time_delta < datetime.timedelta(0):
                 # Negitive time should indicate no pong reply so consider the
                 # websocket disconnected.
                 self._error_reason = ERROR_PING_TIMEOUT
                 await OpenEVSEWebsocket.state.fset(self, STATE_DISCONNECTED)
 
-        data = json.dumps({"ping": 1})
+        data = {"ping": 1}
         _LOGGER.debug("Sending message: %s to websocket.", data)
         try:
-            await self._client.send_str(data)
-            self._ping = datetime.datetime.now()
-            _LOGGER.debug("Ping message sent.")
+            if self._client:
+                await self._client.send_json(data)
+                self._ping = datetime.datetime.now()
+                _LOGGER.debug("Ping message sent.")
+            else:
+                _LOGGER.warning("Websocket client not found.")
         except TypeError as err:
             _LOGGER.error("Attempt to send ping data failed: %s", err)
+        except ValueError as err:
+            _LOGGER.error("Error parsing data: %s", err)
+        except RuntimeError as err:
+            _LOGGER.debug("Websocket connection issue: %s", err)
+            await OpenEVSEWebsocket.state.fset(self, STATE_DISCONNECTED)
         except Exception as err:  # pylint: disable=broad-exception-caught
-            _LOGGER.error("Problem sending ping request: %s", err)
+            _LOGGER.debug("Problem sending ping request: %s", err)
             await OpenEVSEWebsocket.state.fset(self, STATE_DISCONNECTED)
